@@ -28,6 +28,15 @@ from .lib import signed_digest_algo
 from .pkcs11_handle import PKCS11Session
 
 
+def _append_extensions(exts: Extensions, extensions: Extensions, ignore_auth_exts: Optional[bool]) -> None:
+    for _, extension in enumerate(extensions):
+        # Ignore auth exts, should be set by CA not by the requester anyway
+        if ignore_auth_exts is not None and ignore_auth_exts is True:
+            if extension["extn_id"].dotted in ["2.5.29.35", "2.5.29.14", "1.3.6.1.5.5.7.1.1", "2.5.29.31"]:
+                continue
+        exts.append(extension)
+
+
 def _request_to_tbs_certificate(
     csr_pem: str, keep_csr_extensions: Optional[bool], ignore_auth_exts: Optional[bool]
 ) -> TbsCertificate:
@@ -44,17 +53,12 @@ def _request_to_tbs_certificate(
     if keep_csr_extensions is not None and keep_csr_extensions is False:
         return tbs
 
+    # Set CSR extensions into the tbc certificate
     exts = Extensions()
     attrs = req["certification_request_info"]["attributes"]
     for _, attr in enumerate(attrs):
         for _, extensions in enumerate(attr["values"]):
-            for _, extension in enumerate(extensions):
-                # Ignore auth exts, should be set by CA not bby the requester anyway
-                if ignore_auth_exts is not None and ignore_auth_exts is True:
-                    if extension["extn_id"].dotted in ["2.5.29.35", "2.5.29.14", "1.3.6.1.5.5.7.1.1", "2.5.29.31"]:
-                        continue
-
-                exts.append(extension)
+            _append_extensions(exts, extensions, ignore_auth_exts)
 
     if len(exts) > 0:
         tbs["extensions"] = exts
